<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_plugins_/mutualisation/trunk/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'install_bd_cree' => 'La base de données @nombase@ a été créée',
	'install_bd_echec' => 'La création de la base de données @nombase@ a échoué.',
	'install_bd_reessayer' => 'Réessayer...',
	'install_code' => 'Veuillez entrer le code d’activation du site :',
	'install_code_panel' => 'Veuillez entrer votre mot de passe habituel ou le code d’activation fourni par l’hébergeur :',
	'install_creation_bd' => 'Création de la base de données @nombase@',
	'install_creation_bd_site' => 'Création de la base de données du site ',
	'install_creation_bd_site_2' => 'La base de données @base@ a été créée pour le site @site@.',
	'install_creation_rep_ok_1' => 'Création des répertoires OK. Vous pouvez ',
	'install_creation_rep_ok_2' => 'continuer...',
	'install_creation_repertoire' => 'Création du répertoire du site (@repertoire@)',
	'install_creation_site' => 'Creation du site @site@',
	'install_creer_bd_1' => 'Voulez-vous ',
	'install_creer_bd_2' => 'créer cette base ?',
	'install_creer_rep_1' => 'Voulez-vous ',
	'install_creer_rep_2' => 'créer les répertoires de ce site ?',
	'install_err' => 'Erreur...',
	'install_no_data_connexion' => 'Les données de connexion @connexion@ ne sont pas définies, impossible de créer automatiquement la base.',
	'install_rep_bd_ok' => 'Les répertoires et la base de donnée du site sont maintenant créés.',
	'install_repertoire_creer' => 'Veuillez créer le répertoire @repertoire@ et ses sous répertoires :',
	'install_repertoire_inaccessible' => 'Le répertoire @repertoire@ n’est pas accessible en écriture',
	'install_repertoire_noexist' => 'Le répertoire du site (@repertoire@) n’existe pas',
	'install_reps_crees' => 'Les répertoires du site @site@ ont été créés.',
	'install_site' => 'Installation de votre site SPIP',
	'install_spip_1' => 'Vous pouvez ',
	'install_spip_2' => 'poursuivre l’installation de SPIP',
	'install_spip_3' => 'Vous pouvez <a href="@url@">poursuivre l’installation de SPIP</a>.',

	// M
	'message_site_desactive' => 'Veuillez contacter l’<a href="@lien@">hébergeur</a> pour de plus amples détails',

	// S
	'site_non_active' => 'Ce site n’a pas encore été validé par un administrateur.',
	'site_non_demande' => 'Ce site n’existe pas.',
	'site_supprime' => 'Ce site est en attente de suppression définitive.',
	'site_suspendu' => 'Ce site est suspendu.'
);

?>
